==> apache-drill-1.17.0-src.zip: apache-drill-1.17.0-src/metastore/metastore-api/src/main/java/org/apache/drill/metastore/MetastoreFieldDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.metastore;

import org.apache.drill.metastore.metadata.MetadataType;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation used to determine to which metadata types Metastore units fields belong.
 * Mainly used when obtaining field information using reflection.
 * Only fields annotated with this annotation are considered to be part of component
 * metadata unit, non-annotated fields will be ignored.
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.FIELD})
public @interface MetastoreFieldDefinition {

  /**
   * Indicated metadata types to which field belongs to.
   *
   * @return array of metadata types field belongs to
   */
  MetadataType[] scopes();
}

==> apache-drill-1.22.0-src.zip: apache-drill-1.22.0-src/metastore/metastore-api/src/main/java/org/apache/drill/metastore/MetastoreFieldDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.metastore;

import org.apache.drill.metastore.metadata.MetadataType;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation used to determine to which metadata types Metastore units fields belong.
 * Mainly used when obtaining field information using reflection.
 * Only fields annotated with this annotation are considered to be part of component
 * metadata unit, non-annotated fields will be ignored.
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.FIELD})
public @interface MetastoreFieldDefinition {

  /**
   * Indicates Metastore column which can be used in select or filter.
   *
   * @return column enum value
   */
  MetastoreColumn column();

  /**
   * Indicated metadata types to which field belongs to.
   *
   * @return array of metadata types field belongs to
   */
  MetadataType[] scopes();
}
